@@ -16,14 +16,13 @@
  */
 #ifndef _MIMEHANDLER_H_INCLUDED_
 #define _MIMEHANDLER_H_INCLUDED_
-#include "autoconfig.h"
 
 #include <stdio.h>
 #include <stdint.h>
 #include <string>
 
 #include "Filter.h"
-#include "cstr.h"
+#include "pathut.h"
 #include "smallut.h"
 
 class RclConfig;
@@ -166,7 +165,8 @@ protected:
  *     indexedmimetypes (if this is set at all).
  */
 extern RecollFilter *getMimeHandler(const std::string &mtyp, RclConfig *cfg,
-                                    bool filtertypes, const std::string& fn = std::string());
+                                    bool filtertypes, const std::string& fn = std::string(),
+                                    const struct PathStat *stp = nullptr);
 
 /// Free up filter for reuse (you can also delete it)
 extern void returnMimeHandler(RecollFilter *);
@@ -184,6 +184,6 @@ extern bool canIntern(const std::string mimetype, RclConfig *cfg);
 /// Same, getting MIME from doc
 extern bool canIntern(Rcl::Doc *doc, RclConfig *cfg);
 /// Can this MIME type be opened (has viewer def) ?
-extern bool canOpen(Rcl::Doc *doc, RclConfig *cfg);
+extern bool canOpen(Rcl::Doc *doc, RclConfig *cfg, bool useall=false);
 
 #endif /* _MIMEHANDLER_H_INCLUDED_ */
