@@ -75,6 +75,7 @@
 class QCheckBox;
 class QComboBox;
 class QDialogButtonBox;
+class QAbstractButton;
 class QHBoxLayout;
 class QLineEdit;
 class QListWidget;
@@ -119,6 +120,7 @@ public:
     virtual ~ConfPanelWIF() {}
     virtual void storeValues() = 0;
     virtual void loadValues() = 0;
+    virtual bool modified() {return false;}
 };
 
 class ConfPanelW;
@@ -168,10 +170,12 @@ public:
     ConfParamW *findParamW(const QString& varname);
 
     void hideButtons();
+    bool modified();
                       
 public slots:
     void acceptChanges();
     void rejectChanges();
+    void buttonClicked(QAbstractButton*);
     void reloadPanels();
     void setCurrentIndex(int);
     
@@ -205,6 +209,7 @@ public:
     void addParam(ConfParamW *w);
     void addWidget(QWidget *w);
     void storeValues();
+    bool modified();
     void loadValues();
     void endOfList();
     /** Find param widget associated with given variable name */
@@ -239,6 +244,8 @@ public:
         m_strdefault = value;
     }
         
+    virtual bool modified() = 0;
+
 public slots:
     virtual void setEnabled(bool) = 0;
     virtual void storeValue() = 0;
@@ -270,6 +277,7 @@ public:
                    const QString& lbltxt,
                    const QString& tltptxt, bool deflt = false);
     virtual void loadValue();
+    virtual bool modified();
     virtual void storeValue();
     virtual void setImmediate();
 public slots:
@@ -297,6 +305,7 @@ public:
                   int maxvalue = INT_MAX,
                   int defaultvalue = 0);
     virtual void loadValue();
+    virtual bool modified();
     virtual void storeValue();
     virtual void setImmediate();
 public slots:
@@ -319,6 +328,7 @@ public:
                   const QString& lbltxt,
                   const QString& tltptxt);
     virtual void loadValue();
+    virtual bool modified();
     virtual void storeValue();
     virtual void setImmediate();
 public slots:
@@ -340,6 +350,7 @@ public:
                    const QString& lbltxt,
                    const QString& tltptxt, const QStringList& sl);
     virtual void loadValue();
+    virtual bool modified();
     virtual void storeValue();
     virtual void setList(const QStringList& sl);
     virtual void setImmediate();
@@ -362,6 +373,7 @@ public:
                  const QString& lbltxt,
                  const QString& tltptxt, bool isdir = false);
     virtual void loadValue();
+    virtual bool modified();
     virtual void storeValue();
     virtual void setImmediate();
 protected slots:
@@ -390,6 +402,7 @@ public:
                  const QString& lbltxt,
                  const QString& tltptxt);
     virtual void loadValue();
+    virtual bool modified();
     virtual void storeValue();
     QListWidget *getListBox() {
         return m_lb;
@@ -455,55 +468,6 @@ extern void setSzPol(QWidget *w, QSizePolicy::Policy hpol,
                      QSizePolicy::Policy vpol,
                      int hstretch, int vstretch);
 
-#ifdef ENABLE_XMLCONF
-/**
- * Interpret an XML string and create a configuration interface. XML sample:
- *
- * <confcomments>
- *   <filetitle>Configuration file parameters for upmpdcli</filetitle>
- *   <grouptitle>MPD parameters</grouptitle>
- *   <var name="mpdhost" type="string">
- *     <brief>Host MPD runs on.</brief>
- *     <descr>Defaults to localhost. This can also be specified as -h</descr>
- *   </var>
- *   mpdhost = default-host
- *   <var name="mpdport" type="int" values="0 65635 6600">
- *     <brief>IP port used by MPD</brief>. 
- *     <descr>Can also be specified as -p port. Defaults to the...</descr>
- *   </var>
- *   mpdport = defport
- *   <var name="ownqueue" type="bool" values="1">
- *     <brief>Set if we own the MPD queue.</brief>
- *     <descr>If this is set (on by default), we own the MPD...</descr>
- *   </var>
- *   ownqueue = 
- * </confcomments>
- *
- * <grouptitle> creates a panel in which the following <var> are set.
- * The <var> attributes should be self-explanatory. "values"
- * is used for different things depending on the var type
- * (min/max, default, str list). Check the code about this. 
- * type values: "bool" "int" "string" "cstr" "cstrl" "fn" "dfn" "strl" "dnl"
- *
- * The XML would typically exist as comments inside a reference configuration
- * file (ConfSimple can extract such comments).
- *
- * This means that the reference configuration file can generate both
- * the documentation and the GUI interface.
- * 
- * @param xml the input xml
- * @param[output] toptxt the top level XML text (text not inside <var>, 
- *   normally commented variable assignments). This will be evaluated
- *   as a config for default values.
- * @lnkf factory to create the objects which link the GUI to the
- *   storage mechanism.
- */
-extern ConfTabsW *xmlToConfGUI(const std::string& xml,
-                               std::string& toptxt,
-                               ConfLinkFact* lnkf,
-                               QWidget *parent);
-#endif
-
-}
+} // namespace confgui
 
 #endif /* _confgui_h_included_ */
