@@ -164,7 +164,7 @@ public:
     string *m_sk{nullptr};
 };
 
-string sknull;
+static string sknull;
 static MyConfLinkFactRCL conflinkfactory;
 
 void ConfIndexW::showPrefs(bool modal)
@@ -235,8 +235,10 @@ bool ConfIndexW::setupTopPanel(int idx)
 {
     m_w->addParam(idx, ConfTabsW::CFPT_DNL, "topdirs", 
                   tr("Start folders"),
-                  tr("The list of folders/directories to be indexed. "
-                     "Sub-folders will be recursively processed. Default: your home."));
+                  tr("The list of folders/directories to be indexed, recursively with their "
+                     "sub-folders.<br>"
+                     "The '~' character expands to your home directory, which is the default "
+                     "initial value."));
 
     ConfParamW *cparam = m_w->addParam(
         idx, ConfTabsW::CFPT_DNL, "skippedPaths", tr("Skipped paths"),
@@ -317,8 +319,8 @@ bool ConfIndexW::setupTopPanel(int idx)
     m_w->enableLink(bparam, cparam, true);
 
     m_w->addParam(
-        idx, ConfTabsW::CFPT_FN, "dbdir", tr("Database directory name"),
-        tr("The name for a directory where to store the index<br>"
+        idx, ConfTabsW::CFPT_FN, "dbdir", tr("Database directory"),
+        tr("The name or path for a directory where to store the index<br>"
            "A non-absolute path is taken relative to the "
            "configuration directory. The default is 'xapiandb'."), true);
     m_w->addParam(idx, ConfTabsW::CFPT_STR, "unac_except_trans",
