@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2005-2020 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -23,14 +23,11 @@ class QPushButton;
 
 class CronToolW : public QDialog, public Ui::CronToolW {
     Q_OBJECT
-    public:
+public:
     CronToolW(QWidget * parent = 0) 
-    : QDialog(parent),
-      enableButton(0),
-      disableButton(0)
-    {
-    setupUi(this);
-    init();
+        : QDialog(parent), enableButton(0), disableButton(0) {
+        setupUi(this);
+        init();
     }
     QPushButton *enableButton;
     QPushButton *disableButton;
@@ -41,7 +38,6 @@ private slots:
 private:
     void init();
     void changeCron(bool enable);
-    
 };
 
 
