@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 Jean-Francois Dockes 
+/* Copyright (C) 2005-2025 Jean-Francois Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -23,8 +23,8 @@
 #include <set>
 #include <tuple>
 
-#include <qstring.h>
-#include <qstringlist.h>
+#include <QString>
+#include <QStringList>
 
 /** Holder for preferences (gets saved to user Qt prefs) */
 class PrefsPack {
@@ -51,10 +51,14 @@ public:
     std::string  creslistformat;
 
     enum ColorScheme {CS_LIGHT, CS_DARK, CS_SYSTEM};
-    int colorscheme{0};
+#if (defined(_WIN32) || defined(__APPLE__)) && (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
+    int colorscheme{CS_SYSTEM};
+#else
+    int colorscheme{CS_LIGHT};
+#endif
 
     // Dark mode set: both qss and css will use the base + dark style and then the possible user
-    // style
+    // style. Computed on startup/style change. Not saved.
     bool darkMode;
 
     // This is either empty or the contents of the recoll-dark.css file if we are in dark mode.
@@ -169,6 +173,7 @@ public:
     bool singleapp{false};
     int previewLinesOverAnchor{4};
     QString uilanguage;
+    bool previewdarkbg{false};
     /*INSERTHERE*/
 
     // See widgets/qxtconfirmationmessage.
@@ -184,7 +189,8 @@ public:
     std::string stemlang();
 
     // HTML Header contents for both the result list, the snippets window and others
-    std::string htmlHeaderContents(bool nouser=false);
+    enum HHC_Opts {HHC_NOUSER=1, HHC_NODARK=2};
+    std::string htmlHeaderContents(int opts=0);
     std::string snipCSS();
     
     // MIME types for which we prefer to use stored text from preview
