@@ -15,6 +15,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "autoconfig.h" // For ENABLE_SEMANTIC
+
 #include <iostream>
 
 #include "rclmain_w.h"
@@ -127,6 +129,13 @@ void RclMain::buildMenus()
     actSSQuery->setCheckable(true);
     sstypGroup->addAction(actSSQuery);
     queryMenu->addAction(actSSQuery);
+#ifdef ENABLE_SEMANTIC
+    auto actSSSem = new QAction(tr("Semantic"), this);
+    actSSSem->setData(QVariant(SSearch::SST_SEM));
+    actSSSem->setCheckable(true);
+    sstypGroup->addAction(actSSSem);
+    queryMenu->addAction(actSSSem);
+#endif // SEMANTIC
     queryMenu->addSeparator();
     queryMenu->addAction(enbSynAction);
     queryMenu->addSeparator();
