@@ -25,7 +25,7 @@
 #include "ui_spell.h"
 class SpellW : public QWidget, public Ui::SpellBase
 {
-    Q_OBJECT;
+    Q_OBJECT
 public:
     SpellW(QWidget* parent = 0) 
         : QWidget(parent), m_prevmode(TYPECMB_NONE) {
@@ -42,7 +42,7 @@ public slots:
     virtual void wordChanged(const QString&);
     virtual void textDoubleClicked();
     virtual void textDoubleClicked(int, int);
-    virtual void setMode(comboboxchoice);
+    virtual void setMode(SpellW::comboboxchoice);
 
 private slots:
     virtual void onModeChanged(int);
