@@ -14,7 +14,7 @@
  *   Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
-#include "autoconfig.h"
+#include "autoconfig.h" // For ENABLE_SEMANTIC
 
 #include <sstream>
 #include <set>
@@ -134,7 +134,7 @@ QVariant RclCompleterModel::data(const QModelIndex &index, int role) const
             LOGDEB1("RclCompleterModel::data: returning pixmap\n");
             return index.row() < firstfromindex ? QVariant(clockPixmap) : QVariant(interroPixmap);
         } else {
-            LOGDEB1("RclCompleterModel::data: return: " << qs2u8s(currentlist[index.row()]) << "\n");
+            LOGDEB1("RclCompleterModel::data: return: " << qs2u8s(currentlist[index.row()].first) << "\n");
             return QVariant(currentlist[index.row()].first);
         }
     } else if (index.column() == 1 && prefs.showcompleterhitcounts) {
@@ -207,7 +207,9 @@ void SSearch::init()
     searchTypCMB->addItem(tr("All terms"));
     searchTypCMB->addItem(tr("File name"));
     searchTypCMB->addItem(tr("Query language"));
-    
+#ifdef ENABLE_SEMANTIC
+    searchTypCMB->addItem(tr("Semantic"));
+#endif
     connect(queryText, SIGNAL(returnPressed()), this, SLOT(startSimpleSearch()));
     connect(queryText, SIGNAL(textChanged(const QString&)),
             this, SLOT(searchTextChanged(const QString&)));
@@ -602,23 +604,32 @@ bool SSearch::startSimpleSearch(const std::string& u8, int maxexp)
             if (tp == SST_ANY) {
                 xml << "  <SM>OR</SM>\n";
                 clp = new Rcl::SearchDataClauseSimple(Rcl::SCLT_OR, u8);
-            } else {
+            } else if (tp == SST_ALL) {
                 xml << "  <SM>AND</SM>\n";
                 clp = new Rcl::SearchDataClauseSimple(Rcl::SCLT_AND, u8);
+#ifdef ENABLE_SEMANTIC
+            } else if (tp == SST_SEM) {
+                xml << "  <SM>SEM</SM>\n";
+                clp = new Rcl::SearchDataClauseSimple(Rcl::SCLT_AND, u8);
+#endif // SEMANTIC
+            } else {
+                std::cerr << "UNEXPECTED SEARCH TYPE\n";
+                abort();
             }
         }
         sdata->addClause(clp);
     }
 
-    if (prefs.ssearchAutoPhrase && rcldb) {
-        xml << "  <AP/>\n";
-        sdata->maybeAddAutoPhrase(*rcldb, 
-                                  prefs.ssearchAutoPhraseThreshPC / 100.0);
+    if (tp != SST_SEM) {
+        if (prefs.ssearchAutoPhrase && rcldb) {
+            xml << "  <AP/>\n";
+            sdata->maybeAddAutoPhrase(*rcldb, prefs.ssearchAutoPhraseThreshPC / 100.0);
+        }
+        if (maxexp != -1) {
+            sdata->setMaxExpand(maxexp);
+        }
     }
-    if (maxexp != -1) {
-        sdata->setMaxExpand(maxexp);
-    }
-
+    
     for (const auto& dbdir : prefs.activeExtraDbs) {
         xml << "  <EX>" << base64_encode(dbdir) << "</EX>";
     }
