@@ -21,7 +21,6 @@
 #include <unordered_map>
 #include <vector>
 
-#include "smallut.h"
 #include "rclutil.h"
 
 namespace Rcl {
@@ -137,7 +136,7 @@ public:
 
     // During indexing: only fields from extended attributes were set, no
     // doc content. Allows for faster reindexing of existing doc
-    bool onlyxattr{false};
+    bool metaonly{false};
 
     ///////////////////////////////////////////////////////////////////
 
@@ -163,7 +162,7 @@ public:
         xdocid = 0;
         haspages = false;
         haschildren = false;
-        onlyxattr = false;
+        metaonly = false;
     }
 
     // Copy ensuring no shared string data, for threading issues.
