@@ -249,8 +249,8 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 
     if (m_minSize != -1 || m_maxSize != -1) {
         Xapian::Query sq;
-        string min = lltodecstr(m_minSize);
-        string max = lltodecstr(m_maxSize);
+        string min = std::to_string(m_minSize);
+        string max = std::to_string(m_maxSize);
         if (m_minSize == -1) {
             string value(max);
             leftzeropad(value, 12);
@@ -372,7 +372,7 @@ public:
             m_lastpos = ipos;
         bool noexpand = be ? m_ts->nostemexp() : true;
         LOGDEB1("TermProcQ::takeword: pushing [" << term << "] pos " <<
-                pos << " noexp " << noexpand << "\n");
+                ipos << " noexp " << noexpand << "\n");
         if (m_terms[ipos].size() < term.size()) {
             m_terms[ipos] = term;
             m_nste[ipos] = noexpand;
@@ -827,18 +827,17 @@ bool SearchDataClauseSimple::processUserString(
     m_curcl = 0;
     const StopList stops = db.getStopList();
 
-    // Simple whitespace-split input into user-level words and
-    // double-quoted phrases: word1 word2 "this is a phrase". 
+    // Simple whitespace-split input into user-level words and double-quoted phrases: word1 word2
+    // "this is a phrase".
     //
-    // The text splitter may further still decide that the resulting
-    // "words" are really phrases, this depends on separators:
-    // [paul@dom.net] would still be a word (span), but [about-me]
-    // will probably be handled as a phrase.
+    // The text splitter may further still decide that the resulting "words" are really phrases,
+    // this depends on separators: [paul@dom.net] would still be a word (span), but [about-me] will
+    // probably be handled as a phrase.
     vector<string> phrases;
     TextSplit::stringToStrings(iq, phrases);
 
-    // Process each element: textsplit into terms, handle stem/wildcard 
-    // expansion and transform into an appropriate Xapian::Query
+    // Process each element: textsplit into terms, handle stem/wildcard expansion and transform into
+    // an appropriate Xapian::Query
     try {
         for (auto& wordorphrase : phrases) {
             LOGDEB0("strToXapianQ: phrase/word: [" << wordorphrase << "]\n");
@@ -862,7 +861,7 @@ bool SearchDataClauseSimple::processUserString(
             // and the last position
 
             // The term processing pipeline:
-            // split -> [unac/case ->] stops -> store terms
+            //   split -> [unac/case ->] stops -> store terms
             TermProcQ tpq;
             TermProc *nxt = &tpq;
             TermProcStop tpstop(nxt, stops); nxt = &tpstop;
@@ -933,6 +932,8 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p)
     LOGDEB("SearchDataClauseSimple::toNativeQuery: fld [" << m_field <<
            "] val [" << m_text << "] stemlang [" << getStemLang() << "]\n");
 
+    m_hldata.clear();
+
     // Transform (in)equalities into a range query
     switch (getrel()) {
     case REL_EQUALS:
@@ -975,8 +976,12 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p)
 
     vector<Xapian::Query> pqueries;
     std::string pbterm;
-    if (!processUserString(db, m_text, m_reason, pbterm, &pqueries))
+    if (m_text.empty()) {
+        // Simpler to just special-case the empty case here.
+        pqueries = std::vector<Xapian::Query>{Xapian::Query(std::string())};
+    } else if (!processUserString(db, m_text, m_reason, pbterm, &pqueries)) {
         return false;
+    }
     if (pqueries.empty()) {
         LOGDEB("SearchDataClauseSimple: " << m_text << " resolved to null query\n");
         if (!pbterm.empty()) 
@@ -999,6 +1004,9 @@ bool SearchDataClauseRange::toNativeQuery(Rcl::Db &db, void *p)
 {
     LOGDEB("SearchDataClauseRange::toNativeQuery: " << m_field <<
            " :[" << m_text << ".." << m_t2 << "]\n");
+
+    m_hldata.clear();
+
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
@@ -1022,8 +1030,8 @@ bool SearchDataClauseRange::toNativeQuery(Rcl::Db &db, void *p)
     string errstr;
     try {
         if (m_text.empty()) {
-            *qp = Xapian::Query(Xapian::Query::OP_VALUE_LE,
-                                ftp->valueslot, convert_field_value(*ftp, m_t2));
+            *qp = Xapian::Query(Xapian::Query::OP_VALUE_LE, ftp->valueslot,
+                                convert_field_value(*ftp, m_t2));
         } else if (m_t2.empty()) {
             *qp = Xapian::Query(Xapian::Query::OP_VALUE_GE, ftp->valueslot,
                                 convert_field_value(*ftp, m_text));
@@ -1054,6 +1062,8 @@ bool SearchDataClauseRange::toNativeQuery(Rcl::Db &db, void *p)
 // file names
 bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p)
 {
+    m_hldata.clear();
+
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
@@ -1075,6 +1085,9 @@ bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p)
 bool SearchDataClausePath::toNativeQuery(Rcl::Db &db, void *p)
 {
     LOGDEB("SearchDataClausePath::toNativeQuery: [" << m_text << "]\n");
+
+    m_hldata.clear();
+    
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
@@ -1133,6 +1146,8 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p)
 {
     LOGDEB("SearchDataClauseDist::toNativeQuery\n");
 
+    m_hldata.clear();
+
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
